@@ -23,14 +23,12 @@ void usage(void)
     exit(2);
 }
 
-void main(int argc, char **argv)
+int main(int argc, char **argv)
 {
     int x, y;
     char buffer[2];
-#ifndef SVGA_AOUT
     int vgamode;
     int key, retval = 0;
-#endif
 
     if (argc != 3)
 	usage();
@@ -39,10 +37,6 @@ void main(int argc, char **argv)
     if (1 != sscanf(argv[2], "%d%c", &y, buffer))
 	usage();
 
-#ifdef SVGA_AOUT
-    puts("Sorry, this demo needs to be compiled with ELF for proper operation!");
-    exit(1);
-#else
     vga_init();
     vgamode = vga_getdefaultmode();
     if (vgamode == -1)
@@ -75,5 +69,4 @@ void main(int argc, char **argv)
     vga_setmode(TEXT);
 
     exit(retval);
-#endif
 }
