@@ -33,7 +33,7 @@ static inline int RGB2BGR(int c)
 /* However bswap is not supported by 386 */
 
     if (MODEFLAGS & MODEFLAG_24BPP_REVERSED)
-#ifdef __alpha__
+#ifdef NO_ASSEMBLY
 	c = ((c >> 0) & 0xff) << 16 |
 	    ((c >> 8) & 0xff) << 8 |
 	    ((c >> 16) & 0xff) << 0;
@@ -80,14 +80,9 @@ static void notimplemented(char *s)
 
 void __svgalib_driver8_setpixel(int x, int y, int c)
 {
-#ifdef __alpha__
-    vga_setcolor(c);
-    vga_drawpixel(x, y);
-#else
     char *vp;
     ASSIGNVP8(x, y, vp);
     *vp = c;
-#endif
 }
 
 void __svgalib_driver8p_setpixel(int x, int y, int c)
@@ -144,18 +139,18 @@ void __svgalib_driver8_fillbox(int x, int y, int w, int h, int c)
     int i;
     ASSIGNVP8(x, y, vp);
     for (i = 0; i < h; i++) {
-	__memset(vp, c, w);
-	vp += BYTEWIDTH;
+		__memset(vp, c, w);
+		vp += BYTEWIDTH;
     }
 }
 
 void __svgalib_driver8a_fillbox(int x, int y, int w, int h, int c)
 {
     if (w * h < 128)
-	(*__svgalib_nonaccel_fillbox)(x, y, w, h, c);
+		(*__svgalib_nonaccel_fillbox)(x, y, w, h, c);
     else {
-	vga_accel(ACCEL_SETFGCOLOR, c);
-	vga_accel(ACCEL_FILLBOX, x, y, w, h);
+		vga_accel(ACCEL_SETFGCOLOR, c);
+		vga_accel(ACCEL_FILLBOX, x, y, w, h);
     }
 }
 
@@ -169,7 +164,7 @@ void __svgalib_driver8p_fillbox(int x, int y, int w, int h, int c)
     vp &= 0xffff;
     vga_setpage(page);
     for (i = 0; i < h; i++) {
-	if (vp + w > 0x10000)
+	if (vp + w > 0x10000) {
 	    if (vp >= 0x10000) {
 		page++;
 		vga_setpage(page);
@@ -182,6 +177,7 @@ void __svgalib_driver8p_fillbox(int x, int y, int w, int h, int c)
 		vp = (vp + BYTEWIDTH) & 0xffff;
 		continue;
 	    }
+        };
 	__memset(VBUF + vp, c, w);
 	vp += BYTEWIDTH;
     }
@@ -213,7 +209,7 @@ void __svgalib_driver8p_putbox(int x, int y, int w, int h, void *b, int bw)
     vp &= 0xffff;
     vga_setpage(page);
     for (i = 0; i < h; i++) {
-	if (vp + w > 0x10000)
+	if (vp + w > 0x10000) {
 	    if (vp >= 0x10000) {
 		page++;
 		vga_setpage(page);
@@ -228,6 +224,7 @@ void __svgalib_driver8p_putbox(int x, int y, int w, int h, void *b, int bw)
 		bp += bw;
 		continue;
 	    }
+        };
 	__memcpy(VBUF + vp, bp, w);
 	bp += bw;
 	vp += BYTEWIDTH;
@@ -259,7 +256,7 @@ void __svgalib_driver8p_getbox(int x, int y, int w, int h, void *b, int bw)
     vp &= 0xffff;
     vga_setpage(page);
     for (i = 0; i < h; i++) {
-	if (vp + w > 0x10000)
+	if (vp + w > 0x10000) {
 	    if (vp >= 0x10000) {
 		page++;
 		vga_setpage(page);
@@ -274,6 +271,7 @@ void __svgalib_driver8p_getbox(int x, int y, int w, int h, void *b, int bw)
 		bp += bw;
 		continue;
 	    }
+        };
 	__memcpy(bp, VBUF + vp, w);
 	bp += bw;
 	vp += BYTEWIDTH;
@@ -469,7 +467,7 @@ void __svgalib_driver16p_fillbox(int x, int y, int w, int h, int c)
     vp &= 0xffff;
     vga_setpage(page);
     for (i = 0; i < h; i++) {
-	if (vp + w * 2 > 0x10000)
+	if (vp + w * 2 > 0x10000) {
 	    if (vp >= 0x10000) {
 		page++;
 		vga_setpage(page);
@@ -482,6 +480,7 @@ void __svgalib_driver16p_fillbox(int x, int y, int w, int h, int c)
 		vp = (vp + BYTEWIDTH) & 0xffff;
 		continue;
 	    }
+        };
 	__memset2(VBUF + vp, c, w);
 	vp += BYTEWIDTH;
     }
@@ -750,7 +749,7 @@ void __svgalib_driver24p_fillbox(int x, int y, int w, int h, int c)
     vga_setpage(page);
     if (RGBEQUAL(c)) {
 	for (i = 0; i < h; i++) {
-	    if (vp + w * 3 > 0x10000)
+	    if (vp + w * 3 > 0x10000) {
 		if (vp >= 0x10000) {
 		    page++;
 		    vga_setpage(page);
@@ -763,12 +762,13 @@ void __svgalib_driver24p_fillbox(int x, int y, int w, int h, int c)
 		    vp = (vp + BYTEWIDTH) & 0xffff;
 		    continue;
 		}
+            };
 	    __memset(VBUF + vp, c, w * 3);
 	    vp += BYTEWIDTH;
 	}
     } else
 	for (i = 0; i < h; i++) {
-	    if (vp + w * 3 > 0x10000)
+	    if (vp + w * 3 > 0x10000) {
 		if (vp >= 0x10000) {
 		    page++;
 		    vga_setpage(page);
@@ -798,6 +798,7 @@ void __svgalib_driver24p_fillbox(int x, int y, int w, int h, int c)
 		    vp = (vp + BYTEWIDTH) & 0xffff;
 		    continue;
 		}
+            };
 	    __memset3(VBUF + vp, c, w);
 	    vp += BYTEWIDTH;
 	}
@@ -838,7 +839,7 @@ static void driver24_rev_putbox(int x, int y, int w, int h, void *b, int bw)
     vp &= 0xffff;
     vga_setpage(page);
     for (i = 0; i < h; i++) {
-	if (vp + w > 0x10000)
+	if (vp + w > 0x10000) {
 	    if (vp >= 0x10000) {
 		page++;
 		vga_setpage(page);
@@ -878,6 +879,7 @@ static void driver24_rev_putbox(int x, int y, int w, int h, void *b, int bw)
 		bp += bw;
 		continue;
 	    }
+        };
 	RGB_swapped_memcpy(VBUF + vp, bp, w);
 	bp += bw;
 	vp += BYTEWIDTH;
@@ -942,7 +944,7 @@ static void driver24_rev_getbox(int x, int y, int w, int h, void *b, int bw)
     vp &= 0xffff;
     vga_setpage(page);
     for (i = 0; i < h; i++) {
-	if (vp + w > 0x10000)
+	if (vp + w > 0x10000) {
 	    if (vp >= 0x10000) {
 		page++;
 		vga_setpage(page);
@@ -982,6 +984,7 @@ static void driver24_rev_getbox(int x, int y, int w, int h, void *b, int bw)
 		bp += bw;
 		continue;
 	    }
+        };
 	RGB_swapped_memcpy(bp, VBUF + vp, w);
 	bp += bw;
 	vp += BYTEWIDTH;
@@ -1132,7 +1135,7 @@ void __svgalib_driver32_hline(int x1, int y, int x2, int c)
 {
     char *vp;
     ASSIGNVP32(x1, y, vp);
-    __memsetlong(vp, c, x2 - x1 + 1);
+    __memset4(vp, c, x2 - x1 + 1);
 }
 
 void __svgalib_driver32p_hline(int x1, int y, int x2, int c)
@@ -1145,11 +1148,11 @@ void __svgalib_driver32p_hline(int x1, int y, int x2, int c)
     SETWRITEPAGED(vp, rvp, chunksize, page);
     l = (x2 - x1 + 1) * 4;
     if (l <= chunksize)
-	__memsetlong(rvp, c, l / 4);
+	__memset4(rvp, c, l / 4);
     else {
-	__memsetlong(rvp, c, chunksize / 4);
+	__memset4(rvp, c, chunksize / 4);
 	vga_setpage(page + 1);
-	__memsetlong(VBUF, c, (l - chunksize) / 4);
+	__memset4(VBUF, c, (l - chunksize) / 4);
     }
 }
 
@@ -1159,7 +1162,7 @@ void __svgalib_driver32_fillbox(int x, int y, int w, int h, int c)
     int i;
     ASSIGNVP32(x, y, vp);
     for (i = 0; i < h; i++) {
-	__memsetlong(vp, c, w);
+	__memset4(vp, c, w);
 	vp += BYTEWIDTH;
     }
 }
@@ -1174,20 +1177,21 @@ void __svgalib_driver32p_fillbox(int x, int y, int w, int h, int c)
     vp &= 0xffff;
     vga_setpage(page);
     for (i = 0; i < h; i++) {
-	if (vp + w * 4 > 0x10000)
+	if (vp + w * 4 > 0x10000) {
 	    if (vp >= 0x10000) {
 		page++;
 		vga_setpage(page);
 		vp &= 0xffff;
 	    } else {		/* page break within line */
-		__memsetlong(VBUF + vp, c, (0x10000 - vp) / 4);
+		__memset4(VBUF + vp, c, (0x10000 - vp) / 4);
 		page++;
 		vga_setpage(page);
-		__memsetlong(VBUF, c, ((vp + w * 4) & 0xffff) / 4);
+		__memset4(VBUF, c, ((vp + w * 4) & 0xffff) / 4);
 		vp = (vp + BYTEWIDTH) & 0xffff;
 		continue;
 	    }
-	__memsetlong(VBUF + vp, c, w);
+        };
+	__memset4(VBUF + vp, c, w);
 	vp += BYTEWIDTH;
     }
 }
